pub type TableSectionReader<'a> = SectionLimited<'a, TableType>;Expand description
A reader for the table section of a WebAssembly module.
Aliased Type
pub struct TableSectionReader<'a> { /* private fields */ }pub type TableSectionReader<'a> = SectionLimited<'a, TableType>;A reader for the table section of a WebAssembly module.
pub struct TableSectionReader<'a> { /* private fields */ }